/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.common.binaryfile;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.concurrent.CompletableFuture;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.common.binaryfile.BinaryFileTestFactory.TestRequestType;
import de.ozgcloud.common.binaryfile.BinaryFileTestFactory.TestResponseType;

class BinaryFileUploadStreamObserverTest {

	@InjectMocks
	private BinaryFileUploadStreamObserver<TestRequestType, TestResponseType> uploadStreamObserver;
	@Mock
	private CompletableFuture<TestResponseType> future;

	@Mock
	private TestResponseType response;

	@Nested
	class TestOnNext {

		@Test
		void shouldSetFileId() {
			uploadStreamObserver.onNext(response);

			assertThat(uploadStreamObserver.getResponse()).isEqualTo(response);
		}
	}

	@Nested
	class TestOnError {

		@Mock
		private Throwable throwable;

		@Test
		void shouldCompleteFutureExceptionally() {
			uploadStreamObserver.onError(throwable);

			verify(future).completeExceptionally(throwable);
		}
	}

	@Nested
	class TestOnCompleted {

		@Test
		void shouldCompleteWithFileId() {
			uploadStreamObserver.onNext(response);

			uploadStreamObserver.onCompleted();

			verify(future).complete(response);
		}
	}
}