/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.common.pdf;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.InputStream;
import java.io.OutputStream;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.common.pdf.fop.FopPdfService;

class PdfServiceTest {

	@InjectMocks
	private PdfService service;

	@Mock
	private FopPdfService fopService;

	@Nested
	class TestCreatePdf {
		private final InputStream templateIn = mock(InputStream.class);
		private final Object model = mock(Object.class);
		private final OutputStream resultOut = mock(OutputStream.class);

		@Test
		void shouldCallService() {
			service.createPdf(templateIn, resultOut, model);

			verify(fopService).createPdf(templateIn, resultOut, model);
		}

		@Test
		void shouldReturnResult() {
			when(fopService.createPdf(any(), any(), any())).thenReturn(resultOut);

			var result = service.createPdf(templateIn, resultOut, model);

			assertThat(result).isSameAs(resultOut);
		}
	}

}
