/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.common.test;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.util.Objects;
import java.util.function.Consumer;

import org.apache.commons.io.IOUtils;

public class TestUtils {

	public static final Consumer<Object> DUMMY_CONSUMER = t -> {
	};

	private TestUtils() {
	}

	public static InputStream loadFile(final String fileName) {
		InputStream stream = TestUtils.class.getClassLoader().getResourceAsStream(fileName);
		if (stream == null) {
			throw new RuntimeException("File '" + fileName + "' not found."); // NOSONAR
		}
		return stream;
	}

	public static String loadTextFile(final String fileName) {
		try {
			return IOUtils.toString(loadFile(fileName), StandardCharsets.UTF_8);
		} catch (IOException e) {
			throw new RuntimeException(e); // NOSONAR
		}
	}

	public static String loadTextFile(final String fileName, final String... args) {
		return String.format(loadTextFile(fileName), (Object[]) args);
	}

	public static String addQuote(String str) {
		return Objects.isNull(str) ? "null" : String.format("\"%s\"", str);
	}

	public static byte[] contentStreamToByteArray(InputStream contentStream) {
		var outputStream = new ByteArrayOutputStream();
		try {
			IOUtils.copy(contentStream, outputStream);
		} catch (IOException e) {
			throw new RuntimeException("Error on reading stream", e);
		}

		return outputStream.toByteArray();
	}
}
